@@ -96,7 +96,7 @@ class ProcessHandler(QRunnable):
                 # First: Check if there is somethin in the Queue
                 result = self.return_queue.get(block=True, timeout=0.2)
                 # Seconds: Forward the result (is present)
-                self.operator.operationDone(self.element['Id'], result, self.identifier)
+                self.operator.operationDone(self.element['Id'], self.element['AreaNo'], result, self.identifier)
             except queue.Empty:
                 #logging.debug('return_queue empty')
                 pass
@@ -119,7 +119,7 @@ class ProcessHandler(QRunnable):
             try:
                 result = self.return_queue.get(block=True, timeout=0.2)
 
-                self.operator.operationDone(self.element['Id'], result, self.identifier)
+                self.operator.operationDone(self.element['Id'], self.element['AreaNo'], result, self.identifier)
                 #logging.debug('ProcessHandler::run() - Multiprocessing: execution completed - id: 0x{:08x}, ident: {:04d}, pid: {}'.format(
                 #    self.element['Id'], self.identifier, self.p_0.pid))
             except queue.Empty:
@@ -137,6 +137,11 @@ class ProcessHandler(QRunnable):
 
     def feed(self, data): 
         logging.debug('ProcessHandler::feed() - id: 0x{:08x}, ident: {:04d}'.format(self.element['Id'], self.identifier))
+        """
+        if isinstance(data, ProcCMD):
+            self.cmd_queue.put(data)
+        else:
+        """
         self.cmd_queue.put(ProcCMD(data))
 
 class OperatorStartAll(QRunnable):
@@ -247,18 +252,34 @@ class OperatorCreateProcHandle(QRunnable):
 
     def run(self):
 
-        # check if element is already running
-        if self.element['AllowStream']:
+        # check if inputData is a Stop command
+        bStop = False
+        if isinstance(self.inputData, ProcCMD):
+            bStop = self.inputData.bStop
+
+
+
+        # Check if an already running element has to be stopped
+        if self.element['AllowStream'] or bStop:
             
             runningInstance =  list(filter(lambda item: item[1].element['Id'] == self.element['Id'], self.procHandles.items())) 
             # when runningInstance contains an element forward input data to it
             if runningInstance:
                 # [0] first element in the list, [1] ProcessHandler
                 tagetProc = runningInstance[0][1]
-                tagetProc.feed(self.inputData)
+
+                if not bStop:
+                    tagetProc.feed(self.inputData)
+                else:
+                    tagetProc.stop() # Send Stop command to running process
+
                 return
 
 
+        # return here if inputData is a Stop command
+        if bStop:
+            return
+
         identifier = self.operator.getIdent()
         runElement = ProcessHandler(self.element, self.inputData, identifier, self.operator)
 
@@ -477,7 +498,7 @@ class Operator(QObject):
 
         self.command.emit(command)
 
-    def operationDone(self, id, record, identifier):
+    def operationDone(self, id, area, record, identifier):
 
         logging.debug('Operator::operationDone() result received - id: 0x{:08x}, ident: {:04d}'.format(id, identifier))
 
@@ -485,7 +506,8 @@ class Operator(QObject):
 
             address = {
                 'target'    : 'Element',  
-                'id'        : id                      
+                'id'        : id,
+                'area'      : area            
             }
             cmd = { 
                 'cmd'       : 'ElementText',
